[][src]Struct feedly_api::models::SearchResultItem

pub struct SearchResultItem {
    pub feed_id: String,
    pub subscribers: u32,
    pub title: Option<String>,
    pub description: Option<String>,
    pub website: Option<String>,
    pub last_updated: Option<u64>,
    pub velocity: Option<f32>,
    pub language: Option<String>,
    pub curated: Option<bool>,
    pub featured: Option<bool>,
    pub partial: Option<bool>,
    pub icon_url: Option<String>,
    pub visual_url: Option<String>,
    pub cover_url: Option<String>,
    pub logo: Option<String>,
    pub content_type: Option<String>,
    pub cover_color: Option<String>,
    pub delicious_tags: Option<Vec<String>>,
}

Fields

feed_id: String

The unique, immutable id of this feed.

subscribers: u32

Number of feedly cloud subscribers who have this feed in their subscription list.

title: Option<String>

The feed name.

description: Option<String>

The feed description.

website: Option<String>

The website associated with this feed.

last_updated: Option<u64>

The timestamp, in ms, of the last article received for this feed. This value is useful to find "dormant" feeds (feeds that haven't updated in over 3 months).

velocity: Option<f32>

The average number of articles published weekly. This number is updated every few days.

language: Option<String>

This field is a combination of the language reported by the RSS feed, and the language automatically detected from the feed's content. It might not be accurate, as many feeds misreport it.

curated: Option<bool>

If true, this feed is curated.

featured: Option<bool>

If true, this feed is featured (recommended) for the topic or search query.

partial: Option<bool>

???

icon_url: Option<String>

Url to a small square icon.

visual_url: Option<String>

Url to a larger square icon.

cover_url: Option<String>

Url to a large rectangular background image.

Url to a small suqare icon with transparency.

content_type: Option<String>

The auto-detected type of entries this feed publishes. Values include

  • article (most common)
  • longform (for longer articles)
  • videos (for YouTube, Vimeo and other video-centric feeds)
  • audio (for podcast feeds etc)
cover_color: Option<String>

Hex color for the background cover

delicious_tags: Option<Vec<String>>

???